@@ -1,4 +1,4 @@
-`delete.na` <-
+delete.na <-
 function (x, alternative = c("less", "greater") )
 {
 if (alternative == "less")
@@ -28,4 +28,3 @@ if (alternative == "greater")
     return(b)
 }
 }
-
