@@ -25,10 +25,10 @@ W[3,j]<-B[4,j]
 W[6,j]<-B[5,j]+B[7,j]
 }
 W[,3]<-W[,2]/W[,1]
-W[1:2,4]<-W[1:2,3]/W[3,3]
+W[2,4]<-W[2,3]/W[3,3]
 W[4:5,4]<-W[4:5,3]/W[6,3]
 # Pvalue
-W[1:2,5]<-1-pf(W[1:2,4],W[1:2,1],W[3,1])
+W[2,5]<-1-pf(W[2,4],W[2,1],W[3,1])
 W[4:5,5]<-1-pf(W[4:5,4],W[4:5,1],W[6,1])
 N<-NULL
 N[1]<- name.r
